# SociophysicsDataHandler

Pedestrian dynamics data retriever for the Sociophysics courses at Eindhoven University of Technology.  

[![PyPI](https://img.shields.io/pypi/v/sociophysicsDataHandler)](https://pypi.org/project/sociophysicsDataHandler/)

Authors: Alessandro Corbetta, Cas Pouw, Joris Willems  
mail: a.corbetta@tue.nl  
course webpage: [link](https://osiris.tue.nl/osiris_student_tueprd/OnderwijsCatalogusSelect.do?selectie=cursus&collegejaar=2020&cursus=3QEUS0)


### Installation via pip
```bash
pip install sociophysicsDataHandler

```


### Installation from source
```bash

git clone https://github.com/acorbe/sociophysicsDataHandler.git
pip install -e sociophysicsDataHandler/

```
